CREATE SCHEMA IF NOT EXISTS president_public;

SET search_path TO president_public;

-- ##################################################################

-- The Relations of the US Presidents Database are being created ...

create table State(
	State_Name     varchar(17) not null ,
	Admin_Entered  numeric(3)  null     ,
	Year_Entered   numeric(4)  not null ,
	PRIMARY KEY(State_Name)
);

create table President(
	Pres_Name      varchar(15) not null ,
	Birth_Year     numeric(4)  not null ,
	Years_Serv     numeric(2)  not null ,
	Death_Age      numeric(3)  null     ,
	Party          varchar(12) not null ,
	State_Born     varchar(17) not null ,
	PRIMARY KEY (Pres_Name),
	FOREIGN KEY (State_Born) REFERENCES State
);


create table Pres_Hobby(
	Pres_Name      varchar(15) not null ,
	Hobby          varchar(18) not null ,
	PRIMARY KEY (Pres_Name, Hobby),
	FOREIGN KEY (Pres_Name) REFERENCES President
);

create table Administration(
	Admin_Nr         numeric(3)  not null ,
	Pres_Name        varchar(15) not null ,
	Year_Inaugurated numeric(4)  not null ,
	PRIMARY KEY (Admin_Nr, Pres_Name),
	FOREIGN KEY (Pres_Name) REFERENCES President
);

create table Admin_Pr_Vp(
	Admin_Nr       numeric(3)  not null ,
	Pres_Name      varchar(15) not null ,
	Vice_Pres_Name varchar(17) not null ,
	PRIMARY KEY (Admin_Nr, Pres_Name, Vice_Pres_Name),
	FOREIGN KEY (Admin_Nr, Pres_Name) REFERENCES Administration
);

create table Pres_Marriage(
	Pres_Name      varchar(15) not null ,
	Spouse_Name    varchar(15) not null ,
	Pr_Age         numeric(3)  not null ,
	Sp_Age         numeric(3)  not null ,
	Nr_Children    numeric(2)  not null ,
	Mar_Year       numeric(4)  not null ,
	PRIMARY KEY (Pres_Name, Spouse_Name),
	FOREIGN KEY (Pres_Name) REFERENCES President
);

create table Election(
	Election_Year  numeric(4)  not null,
	Candidate      varchar(20) not null,
  Party          varchar(12) null,
	Votes          numeric(3)  not null,
	Winner_Loser_Indic char(1) not null,
	PRIMARY KEY (Election_Year, Candidate)
);

-- ##################################################################

-- "The Rows for the table STATE(S A Y) are  being inserted ... "
insert into  State values ('Massachusetts',NULL,1776);
insert into  State values ('Pennsylvania',NULL,1776);
insert into  State values ('Virginia',NULL,1776);
insert into  State values ('Connecticut',NULL,1776);
insert into  State values ('South Carolina',NULL,1776);
insert into  State values ('Maryland',NULL,1776);
insert into  State values ('New Jersey',NULL,1776);
insert into  State values ('Georgia',NULL,1776);
insert into  State values ('New Hampshire',NULL,1776);
insert into  State values ('Delawhare',NULL,1776);
insert into  State values ('New York',NULL,1776);
insert into  State values ('North Carolina',NULL,1776);
insert into  State values ('Rhode Island',NULL,1776);
insert into  State values ('Vermont',1,1791);
insert into  State values ('Kentucky',1,1792);
insert into  State values ('Tennesee',2,1796);
insert into  State values ('Ohio',4,1803);
insert into  State values ('Louisiana',6,1812);
insert into  State values ('Indiana',7,1816);
insert into  State values ('Mississippi',8,1817);
insert into  State values ('Illinois',8,1818);
insert into  State values ('Alabama',8,1819);
insert into  State values ('Maine',8,1820);
insert into  State values ('Missouri',9,1821);
insert into  State values ('Arkansas',12,1836);
insert into  State values ('Michigan',12,1837);
insert into  State values ('Florida',14,1845);
insert into  State values ('Texas',15,1845);
insert into  State values ('Iowa',15,1846);
insert into  State values ('Wisconsin',15,1848);
insert into  State values ('California',16,1850);
insert into  State values ('Minnesota',18,1858);
insert into  State values ('Oregon',18,1859);
insert into  State values ('Kansas',18,1861);
insert into  State values ('West Virginia',19,1863);
insert into  State values ('Nevada',19,1864);
insert into  State values ('Nebraska',20,1867);
insert into  State values ('Colorado',22,1876);
insert into  State values ('North Dakota',26,1889);
insert into  State values ('South Dakota',26,1889);
insert into  State values ('Montana',26,1889);
insert into  State values ('Washington',26,1889);
insert into  State values ('Idaho',26,1890);
insert into  State values ('Wyoming',26,1890);
insert into  State values ('Utah',27,1896);
insert into  State values ('Oklahoma',30,1907);
insert into  State values ('New Mexico',31,1912);
insert into  State values ('Arizona',31,1912);
insert into  State values ('Alaska',43,1959);
insert into  State values ('Hawaii',43,1959);

-- ###########################################################################

-- "The Rows for the table PRESIDENT(PN B Y D Pa S) are being inserted ..."
insert into  President values ('Washington G',1732,7,67,'Federalist','Virginia');
insert into  President values ('Adams J',1735,4,90,'Federalist','Massachusetts');
insert into  President values ('Jefferson T',1743,8,83,'Demo-Rep','Virginia');
insert into  President values ('Madison J',1751,8,85,'Demo-Rep','Virginia');
insert into  President values ('Monroe J',1758,8,73,'Demo-Rep','Virginia');
insert into  President values ('Adams J Q',1767,4,80,'Demo-Rep','Massachusetts');
insert into  President values ('Jackson A',1767,8,78,'Democratic','South Carolina');
insert into  President values ('Van Buren M',1782,4,79,'Democratic','New York');
insert into  President values ('Harrison W H',1773,0,68,'Whig','Virginia');
insert into  President values ('Tyler J',1790,3,71,'Whig','Virginia');
insert into  President values ('Polk J K',1795,4,53,'Democratic','North Carolina');
insert into  President values ('Taylor Z',1784,1,65,'Whig','Virginia');
insert into  President values ('Fillmore M',1800,2,74,'Whig','New York');
insert into  President values ('Pierce F',1801,4,64,'Democratic','New Hampshire');
insert into  President values ('Buchanan J',1791,4,77,'Democratic','Pennsylvania');
insert into  President values ('Lincoln A',1809,4,56,'Republican','Kentucky');
insert into  President values ('Johnson A',1808,4,66,'Democratic','North Carolina');
insert into  President values ('Grant U S',1822,8,63,'Republican','Ohio');
insert into  President values ('Hayes R B',1822,4,70,'Republican','Ohio');
insert into  President values ('Garfield J A',1831,0,49,'Republican','Ohio');
insert into  President values ('Arthur C A',1830,3,56,'Republican','Vermont');
insert into  President values ('Cleveland G',1837,8,71,'Democratic','New Jersey');
insert into  President values ('Harrison B',1833,4,67,'Republican','Ohio');
insert into  President values ('McKinley W',1843,4,58,'Republican','Ohio');
insert into  President values ('Roosevelt T',1858,7,60,'Republican','New York');
insert into  President values ('Taft W H',1857,4,72,'Republican','Ohio');
insert into  President values ('Wilson W',1856,8,67,'Democratic','Virginia');
insert into  President values ('Harding W G',1865,2,57,'Republican','Ohio');
insert into  President values ('Coolidge C',1872,5,60,'Republican','Vermont');
insert into  President values ('Hoover H C',1871,4,90,'Republican','Iowa');
insert into  President values ('Roosevelt F D',1882,12,63,'Democratic','New York');
insert into  President values ('Truman H S',1884,7,88,'Democratic','Missouri');
insert into  President values ('Eisenhower D D',1890,8,79,'Republican','Texas');
insert into  President values ('Kennedy J F',1917,2,46,'Democratic','Texas');
insert into  President values ('Johnson L B',1908,5,65,'Democratic','California');
insert into  President values ('Nixon R M',1913,5,81,'Republican','Nebraska');
insert into  President values ('Ford G R',1913,5,93,'Republican','Georgia');
insert into  President values ('Carter J E',1924,4,NULL,'Democratic','Georgia');
insert into  President values ('Reagan R',1911,8,93,'Republican','Illinois');
insert into  President values ('Bush G H W',1924,4,94,'Republican','Massachusetts');
insert into  President values ('Clinton W J',1946,8,NULL,'Democratic','Arkansas');
insert into  President values ('Bush G W',1946,8,NULL,'Republican','Connecticut');
insert into  President values ('Obama B H',1961,8,NULL,'Democratic','Hawaii');
insert into  President values ('Trump D J',1946,4,NULL,'Republican','New York');
insert into  President values ('Biden J R',1942,4,NULL,'Democratic','Pennsylvania');
-- Biden served at least 4 years (elected in 2020, not more known at the time of entering
-- these data into the script (2020/12/20))

-- ###########################################################################

-- "The rows for the table PRES_HOBBY(P H) are being inserted ..."
insert into  Pres_Hobby values ('Adams J Q','Billards');
insert into  Pres_Hobby values ('Adams J Q','Swimming');
insert into  Pres_Hobby values ('Adams J Q','Walking');
insert into  Pres_Hobby values ('Arthur C A','Fishing');
insert into  Pres_Hobby values ('Cleveland G','Fishing');
insert into  Pres_Hobby values ('Coolidge C','Fishing');
insert into  Pres_Hobby values ('Coolidge C','Golf');
insert into  Pres_Hobby values ('Coolidge C','Indian Clubs');
insert into  Pres_Hobby values ('Coolidge C','Mechanical Horse');
insert into  Pres_Hobby values ('Coolidge C','Pitching Hay');
insert into  Pres_Hobby values ('Eisenhower D D','Bridge');
insert into  Pres_Hobby values ('Eisenhower D D','Golf');
insert into  Pres_Hobby values ('Eisenhower D D','Hunting');
insert into  Pres_Hobby values ('Eisenhower D D','Painting');
insert into  Pres_Hobby values ('Eisenhower D D','Fishing');
insert into  Pres_Hobby values ('Garfield J A','Billards');
insert into  Pres_Hobby values ('Harding W G','Golf');
insert into  Pres_Hobby values ('Harding W G','Poker');
insert into  Pres_Hobby values ('Harding W G','Riding');
insert into  Pres_Hobby values ('Harrison B','Hunting');
insert into  Pres_Hobby values ('Hayes R B','Croquet');
insert into  Pres_Hobby values ('Hayes R B','Driving');
insert into  Pres_Hobby values ('Hayes R B','Shooting');
insert into  Pres_Hobby values ('Hoover H C','Fishing');
insert into  Pres_Hobby values ('Hoover H C','Medicine Ball');
insert into  Pres_Hobby values ('Jackson A','Riding');
insert into  Pres_Hobby values ('Jefferson T','Fishing');
insert into  Pres_Hobby values ('Jefferson T','Riding');
insert into  Pres_Hobby values ('Johnson L B','Riding');
insert into  Pres_Hobby values ('Kennedy J F','Sailing');
insert into  Pres_Hobby values ('Kennedy J F','Swimming');
insert into  Pres_Hobby values ('Kennedy J F','Touch Football');
insert into  Pres_Hobby values ('Lincoln A','Walking');
insert into  Pres_Hobby values ('McKinley W','Riding');
insert into  Pres_Hobby values ('McKinley W','Swimming');
insert into  Pres_Hobby values ('McKinley W','Walking');
insert into  Pres_Hobby values ('Nixon R M','Golf');
insert into  Pres_Hobby values ('Roosevelt F D','Fishing');
insert into  Pres_Hobby values ('Roosevelt F D','Sailing');
insert into  Pres_Hobby values ('Roosevelt F D','Swimming');
insert into  Pres_Hobby values ('Roosevelt T','Boxing');
insert into  Pres_Hobby values ('Roosevelt T','Hunting');
insert into  Pres_Hobby values ('Roosevelt T','Jujitsu');
insert into  Pres_Hobby values ('Roosevelt T','Riding');
insert into  Pres_Hobby values ('Roosevelt T','Shooting');
insert into  Pres_Hobby values ('Roosevelt T','Tennis');
insert into  Pres_Hobby values ('Roosevelt T','Wrestling');
insert into  Pres_Hobby values ('Taft W H','Golf');
insert into  Pres_Hobby values ('Taft W H','Riding');
insert into  Pres_Hobby values ('Taylor Z','Riding');
insert into  Pres_Hobby values ('Truman H S','Fishing');
insert into  Pres_Hobby values ('Truman H S','Poker');
insert into  Pres_Hobby values ('Truman H S','Walking');
insert into  Pres_Hobby values ('Van Buren M','Riding');
insert into  Pres_Hobby values ('Washington G','Fishing');
insert into  Pres_Hobby values ('Washington G','Riding');
insert into  Pres_Hobby values ('Wilson W','Golf');
insert into  Pres_Hobby values ('Wilson W','Riding');
insert into  Pres_Hobby values ('Wilson W','Walking');
insert into  Pres_Hobby values ('Reagan R','SDI');
insert into  Pres_Hobby values ('Bush G H W','Sailing');
insert into  Pres_Hobby values ('Clinton W J', 'Running');
insert into  Pres_Hobby values ('Clinton W J', 'Reading');
insert into  Pres_Hobby values ('Clinton W J', 'Crossword Puzzles');
insert into  Pres_Hobby values ('Bush G W', 'Reading');
insert into  Pres_Hobby values ('Bush G W', 'Golf');
insert into  Pres_Hobby values ('Obama B H', 'Basketball');
insert into  Pres_Hobby values ('Obama B H', 'Golf');
insert into  Pres_Hobby values ('Trump D J', 'Golf');
insert into  Pres_Hobby values ('Biden J R', 'Skiing');
insert into  Pres_Hobby values ('Biden J R', 'Football');

-- "The rows of the table ADMINISTRATION(A P Y) are being inserted ..."
insert into  Administration values (1,'Washington G',1789);
insert into  Administration values (2,'Washington G',1793);
insert into  Administration values (3,'Adams J',1797);
insert into  Administration values (4,'Jefferson T',1801);
insert into  Administration values (5,'Jefferson T',1805);
insert into  Administration values (6,'Madison J',1809);
insert into  Administration values (7,'Madison J',1813);
insert into  Administration values (8,'Monroe J',1817);
insert into  Administration values (9,'Monroe J',1821);
insert into  Administration values (10,'Adams J Q',1825);
insert into  Administration values (11,'Jackson A',1829);
insert into  Administration values (12,'Jackson A',1833);
insert into  Administration values (13,'Van Buren M',1837);
insert into  Administration values (14,'Harrison W H',1841);
insert into  Administration values (14,'Tyler J',1841);
insert into  Administration values (15,'Polk J K',1845);
insert into  Administration values (16,'Taylor Z',1849);
insert into  Administration values (16,'Fillmore M',1850);
insert into  Administration values (17,'Pierce F',1853);
insert into  Administration values (18,'Buchanan J',1857);
insert into  Administration values (19,'Lincoln A',1861);
insert into  Administration values (20,'Lincoln A',1865);
insert into  Administration values (20,'Johnson A',1865);
insert into  Administration values (21,'Grant U S',1869);
insert into  Administration values (22,'Grant U S',1873);
insert into  Administration values (23,'Hayes R B',1877);
insert into  Administration values (24,'Garfield J A',1881);
insert into  Administration values (24,'Arthur C A',1881);
insert into  Administration values (25,'Cleveland G',1885);
insert into  Administration values (26,'Harrison B',1889);
insert into  Administration values (27,'Cleveland G',1893);
insert into  Administration values (28,'McKinley W',1897);
insert into  Administration values (29,'McKinley W',1901);
insert into  Administration values (29,'Roosevelt T',1901);
insert into  Administration values (30,'Roosevelt T',1905);
insert into  Administration values (31,'Taft W H',1909);
insert into  Administration values (32,'Wilson W',1913);
insert into  Administration values (33,'Wilson W',1917);
insert into  Administration values (34,'Harding W G',1921);
insert into  Administration values (34,'Coolidge C',1923);
insert into  Administration values (35,'Coolidge C',1925);
insert into  Administration values (36,'Hoover H C',1929);
insert into  Administration values (37,'Roosevelt F D',1933);
insert into  Administration values (38,'Roosevelt F D',1937);
insert into  Administration values (39,'Roosevelt F D',1941);
insert into  Administration values (40,'Roosevelt F D',1945);
insert into  Administration values (40,'Truman H S',1945);
insert into  Administration values (41,'Truman H S',1949);
insert into  Administration values (42,'Eisenhower D D',1953);
insert into  Administration values (43,'Eisenhower D D',1957);
insert into  Administration values (44,'Kennedy J F',1961);
insert into  Administration values (44,'Johnson L B',1963);
insert into  Administration values (45,'Johnson L B',1965);
insert into  Administration values (46,'Nixon R M',1969);
insert into  Administration values (47,'Nixon R M',1973);
insert into  Administration values (47,'Ford G R',1974);
insert into  Administration values (48,'Carter J E',1977);
insert into  Administration values (49,'Reagan R',1981);
insert into  Administration values (50,'Reagan R',1985);
insert into  Administration values (51,'Bush G H W',1989);
insert into  Administration values (52,'Clinton W J',1993);
insert into  Administration values (53,'Clinton W J',1997);
insert into  Administration values (54,'Bush G W',2001);
insert into  Administration values (55,'Bush G W',2005);
insert into  Administration values (56,'Obama B H',2009);
insert into  Administration values (57,'Obama B H',2013);
insert into  Administration values (58,'Trump D J',2017);
insert into  Administration values (59,'Biden J R',2021);

-- "The rows of the table ADMIN_PR_VP(A P V) are being inserted ..."
insert into  Admin_Pr_Vp values (1,'Washington G','Adams J');
insert into  Admin_Pr_Vp values (2,'Washington G','Adams J');
insert into  Admin_Pr_Vp values (3,'Adams J','Jefferson T');
insert into  Admin_Pr_Vp values (4,'Jefferson T','Burr A');
insert into  Admin_Pr_Vp values (5,'Jefferson T','Clinton G');
insert into  Admin_Pr_Vp values (6,'Madison J','Clinton G');
insert into  Admin_Pr_Vp values (7,'Madison J','Gerry E');
insert into  Admin_Pr_Vp values (8,'Monroe J','Tompkins D');
insert into  Admin_Pr_Vp values (9,'Monroe J','Tompkins D');
insert into  Admin_Pr_Vp values (10,'Adams J Q','Calhoun J');
insert into  Admin_Pr_Vp values (11,'Jackson A','Calhoun J');
insert into  Admin_Pr_Vp values (12,'Jackson A','Van Buren M');
insert into  Admin_Pr_Vp values (13,'Van Buren M','Johnson R M');
insert into  Admin_Pr_Vp values (14,'Harrison W H','Tyler J');
insert into  Admin_Pr_Vp values (15,'Polk J K','Dallas G M');
insert into  Admin_Pr_Vp values (16,'Taylor Z','Fillmore M');
insert into  Admin_Pr_Vp values (17,'Pierce F','De Vane King W R');
insert into  Admin_Pr_Vp values (18,'Buchanan J','Breckinridge J C');
insert into  Admin_Pr_Vp values (19,'Lincoln A','Hamlin H');
insert into  Admin_Pr_Vp values (20,'Lincoln A','Johnson A');
insert into  Admin_Pr_Vp values (21,'Grant U S','Colfax S');
insert into  Admin_Pr_Vp values (22,'Grant U S','Wilson H');
insert into  Admin_Pr_Vp values (23,'Hayes R B','Wheeler W');
insert into  Admin_Pr_Vp values (24,'Garfield J A','Arthur C A');
insert into  Admin_Pr_Vp values (25,'Cleveland G','Hendricks T A');
insert into  Admin_Pr_Vp values (26,'Harrison B','Morton L P');
insert into  Admin_Pr_Vp values (27,'Cleveland G','Stevenson A E');
insert into  Admin_Pr_Vp values (28,'McKinley W','Hobart G A');
insert into  Admin_Pr_Vp values (29,'McKinley W','Roosevelt T');
insert into  Admin_Pr_Vp values (30,'Roosevelt T','Fairbanks C W');
insert into  Admin_Pr_Vp values (31,'Taft W H','Sherman J S');
insert into  Admin_Pr_Vp values (32,'Wilson W','Marshall T R');
insert into  Admin_Pr_Vp values (33,'Wilson W','Marshall T R');
insert into  Admin_Pr_Vp values (34,'Harding W G','Coolidge C');
insert into  Admin_Pr_Vp values (35,'Coolidge C','Dawes C G');
insert into  Admin_Pr_Vp values (36,'Hoover H C','Curtis C');
insert into  Admin_Pr_Vp values (37,'Roosevelt F D','Garner J N');
insert into  Admin_Pr_Vp values (38,'Roosevelt F D','Garner J N');
insert into  Admin_Pr_Vp values (39,'Roosevelt F D','Wallace H A');
insert into  Admin_Pr_Vp values (40,'Roosevelt F D','Truman H S');
insert into  Admin_Pr_Vp values (41,'Truman H S','Barkley A W');
insert into  Admin_Pr_Vp values (42,'Eisenhower D D','Nixon R M');
insert into  Admin_Pr_Vp values (43,'Eisenhower D D','Nixon R M');
insert into  Admin_Pr_Vp values (44,'Kennedy J F','Johnson L B');
insert into  Admin_Pr_Vp values (45,'Johnson L B','Humphrey H H');
insert into  Admin_Pr_Vp values (46,'Nixon R M','Agnew S T');
insert into  Admin_Pr_Vp values (47,'Nixon R M','Agnew S T');
insert into  Admin_Pr_Vp values (47,'Nixon R M','Ford G R');
insert into  Admin_Pr_Vp values (47,'Ford G R','Rockefeller N A');
insert into  Admin_Pr_Vp values (48,'Carter J E','Mondale W F');
insert into  Admin_Pr_Vp values (49,'Reagan R','Bush G');
insert into  Admin_Pr_Vp values (50,'Reagan R','Bush G');
insert into  Admin_Pr_Vp values (51,'Bush G H W','Quayle D');
insert into  Admin_Pr_Vp values (52,'Clinton W J','Gore A');
insert into  Admin_Pr_Vp values (53,'Clinton W J','Gore A');
insert into  Admin_Pr_Vp values (54,'Bush G W', 'Cheney R');
insert into  Admin_Pr_Vp values (55,'Bush G W', 'Cheney R');
insert into  Admin_Pr_Vp values (56,'Obama B H', 'Biden J R');
insert into  Admin_Pr_Vp values (57,'Obama B H', 'Biden J R');
insert into  Admin_Pr_Vp values (58,'Trump D J', 'Pence M');
insert into  Admin_Pr_Vp values (59,'Biden J R', 'Harris K D');

-- "The rows of the table PRES_MARRIAGE(PN SN PA SA N M) are being inserted ..."
insert into  Pres_Marriage values ('Washington G','Custis M D',26,27,0,1759);
insert into  Pres_Marriage values ('Adams J','Simth A',28,19,5,1764);
insert into  Pres_Marriage values ('Jefferson T','Skelton M W',28,23,6,1772);
insert into  Pres_Marriage values ('Madison J','Todd D D P',43,26,0,1794);
insert into  Pres_Marriage values ('Monroe J','Kortright E',27,17,3,1786);
insert into  Pres_Marriage values ('Adams J Q','Johnson L C',30,22,4,1797);
insert into  Pres_Marriage values ('Jackson A','Robards R D',26,26,0,1794);
insert into  Pres_Marriage values ('Van Buren M','Hoes H',24,23,4,1807);
insert into  Pres_Marriage values ('Harrison W H','Symmos A T',22,20,10,1795);
insert into  Pres_Marriage values ('Tyler J','Christian L',23,22,8,1813);
insert into  Pres_Marriage values ('Tyler J','Gardiner J',54,24,7,1844);
insert into  Pres_Marriage values ('Polk J K','Chidross S',28,20,0,1824);
insert into  Pres_Marriage values ('Taylor Z','Smith M M',25,21,6,1810);
insert into  Pres_Marriage values ('Fillmore M','Powers A',26,27,2,1826);
insert into  Pres_Marriage values ('Fillmore M','McIntosh C C',58,44,0,1858);
insert into  Pres_Marriage values ('Pierce F','Appleton J M',29,28,3,1834);
insert into  Pres_Marriage values ('Lincoln A','Todd M',33,23,4,1842);
insert into  Pres_Marriage values ('Johnson A','McCardle E',18,16,5,1827);
insert into  Pres_Marriage values ('Grant U S','Dent J B',26,22,4,1848);
insert into  Pres_Marriage values ('Hayes R B','Webb L W',30,21,8,1852);
insert into  Pres_Marriage values ('Garfield J A','Rudolph L',26,26,7,1853);
insert into  Pres_Marriage values ('Arthur C A','Horndon E L',29,22,3,1859);
insert into  Pres_Marriage values ('Cleveland G','Folson F',49,21,5,1886);
insert into  Pres_Marriage values ('Harrison B','Scott C L',20,21,2,1853);
insert into  Pres_Marriage values ('Harrison B','Dimmick M S L',62,37,1,1896);
insert into  Pres_Marriage values ('McKinley W','Saxton I',27,23,2,1871);
insert into  Pres_Marriage values ('Roosevelt T','Lee A H',22,19,1,1880);
insert into  Pres_Marriage values ('Roosevelt T','Carow E K',28,25,5,1886);
insert into  Pres_Marriage values ('Taft W H','Horron H',28,25,3,1886);
insert into  Pres_Marriage values ('Wilson W','Axson E L',28,25,3,1885);
insert into  Pres_Marriage values ('Wilson W','Galt E B',58,43,0,1915);
insert into  Pres_Marriage values ('Harding W G','DeWolfe F K',25,30,0,1891);
insert into  Pres_Marriage values ('Coolidge C','Goodhue G A',33,26,2,1905);
insert into  Pres_Marriage values ('Hoover H C','Henry L',24,23,2,1899);
insert into  Pres_Marriage values ('Roosevelt F D','Roosevelt A E',23,20,6,1905);
insert into  Pres_Marriage values ('Truman H S','Wallace E V',35,34,1,1918);
insert into  Pres_Marriage values ('Eisenhower D D','Doud G',25,19,2,1916);
insert into  Pres_Marriage values ('Kennedy J F','Bouvier J L',36,24,3,1953);
insert into  Pres_Marriage values ('Johnson L B','Taylor C A',26,21,2,1934);
insert into  Pres_Marriage values ('Nixon R M','Ryan T C',27,28,2,1940);
insert into  Pres_Marriage values ('Ford G R','Warren E B',35,30,4,1948);
insert into  Pres_Marriage values ('Carter J E','Smith R',21,18,4,1946);
insert into  Pres_Marriage values ('Reagan R','Wyman J',28,25,2,1940);
insert into  Pres_Marriage values ('Reagan R','Davis N',41,28,2,1952);
insert into  Pres_Marriage values ('Bush G H W','Pierce B',20,19,5,1945);
insert into  Pres_Marriage values ('Clinton W J','Rodham H D',29,27,1,1975);
insert into  Pres_Marriage values ('Bush G W', 'Welch L L',31,31,2,1977);
insert into  Pres_Marriage values ('Obama B H', 'Robinson M L',31,28,2,1992);
insert into  Pres_Marriage values ('Trump D J','Zelnickova I M',30,28,3,1977);
insert into  Pres_Marriage values ('Trump D J','Maples M A',47,30,1,1993);
insert into  Pres_Marriage values ('Trump D J','Knavs M',58,34,1,2005);
insert into  Pres_Marriage values ('Biden J R','Hunter N',23,24,3,1966);
insert into  Pres_Marriage values ('Biden J R','Jacobs J T',34,26,1,1977);

-- "The rows of the table ELECTION(E C P V W) are being inserted ..."
insert into  Election values (1789,'Washington G','Federalist',69,'W');
insert into  Election values (1789,'Adams J','Federalist',34,'L');
insert into  Election values (1789,'Jay J',NULL,9,'L');
insert into  Election values (1789,'Harrison R H',NULL,6,'L');
insert into  Election values (1789,'Rutledge J',NULL,6,'L');
insert into  Election values (1789,'Hancock J',NULL,4,'L');
insert into  Election values (1789,'Clinton G',NULL,3,'L');
insert into  Election values (1789,'Huntington S',NULL,2,'L');
insert into  Election values (1789,'Milton J',NULL,2,'L');
insert into  Election values (1789,'Armstrong J',NULL,1,'L');
insert into  Election values (1789,'Lincoln B',NULL,1,'L');
insert into  Election values (1789,'Telfair E',NULL,1,'L');
insert into  Election values (1792,'Washington G','Federalist',132,'W');
insert into  Election values (1792,'Adams J','Federalist',77,'L');
insert into  Election values (1792,'Clinton G','Demo-Rep',50,'L');
insert into  Election values (1792,'Jefferson T','Demo-Rep',4,'L');
insert into  Election values (1792,'Burr A',NULL,1,'L');
insert into  Election values (1796,'Adams J','Federalist',71,'W');
insert into  Election values (1796,'Jefferson T','Demo-Rep',68,'L');
insert into  Election values (1796,'Pinckney T','Federalist',59,'L');
insert into  Election values (1796,'Burr A','Anti-Fed',30,'L');
insert into  Election values (1796,'Adams S','Demo-Rep',15,'L');
insert into  Election values (1796,'Ellsworth O','Federalist',11,'L');
insert into  Election values (1796,'Clinton G','Demo-Rep',7,'L');
insert into  Election values (1796,'Jay J','Federalist',5,'L');
insert into  Election values (1796,'Iredell J','Federalist',3,'L');
insert into  Election values (1796,'Henry J','Independent',2,'L');
insert into  Election values (1796,'Johnston S','Federalist',2,'L');
insert into  Election values (1796,'Washington G','Federalist',2,'L');
insert into  Election values (1796,'Pinckney C C','Federalist',1,'L');
insert into  Election values (1800,'Jefferson T','Demo-Rep',73,'W');
insert into  Election values (1800,'Burr A','Demo-Rep',73,'L');
insert into  Election values (1800,'Adams J','Federalist',65,'L');
insert into  Election values (1800,'Pinckney C C','Federalist',64,'L');
insert into  Election values (1800,'Jay J','Federalist',1,'L');
-- as there was a tie between Jefferson and Burr, the U.S. House of
-- Representatives voted on who would become president (with one vote
-- per state), and after 36 ballots, Jefferson was elected president
-- and Burr vice president

insert into  Election values (1804,'Jefferson T','Demo-Rep',162,'W');
insert into  Election values (1804,'Pinckney','Federalist',14,'L');
insert into  Election values (1808,'Madison J','Demo-Rep',122,'W');
insert into  Election values (1808,'Pinckney C C','Federalist',47,'L');
insert into  Election values (1808,'Clinton G','Independent',6,'L');
insert into  Election values (1812,'Madison J','Demo-Rep',128,'W');
insert into  Election values (1812,'Clinto D W','Fusion',89,'L');
insert into  Election values (1816,'Monroe J','Demo-Rep',183,'W');
insert into  Election values (1816,'King R','Federalist',34,'L');
insert into  Election values (1820,'Monroe J','Demo-Rep',231,'W');
insert into  Election values (1820,'Adams J Q','Demo-Rep',1,'L');
insert into  Election values (1824,'Adams J Q','Demo-Rep',84,'W');
insert into  Election values (1824,'Jackson A','Demo-Rep',99,'L');
insert into  Election values (1824,'Crawford W H','Demo-Rep',37,'L');
insert into  Election values (1824,'Clay H','Demo-Rep',41,'L');
-- because no candidate received a majority of Electoral College votes,
-- U.S. House of Representatives (as set in the 12th Amendment) elected
-- John Quincy Adams as president in February 1825

insert into  Election values (1828,'Jackson A','Democratic',178,'W');
insert into  Election values (1828,'Adams J Q','Nat. Rep.',83,'L');
insert into  Election values (1832,'Jackson A','Democratic',219,'W');
insert into  Election values (1832,'Clay H','Nat. Rep.',49,'L');
insert into  Election values (1832,'Wirt W','Anti-Masonic',7,'L');
insert into  Election values (1832,'Floyd J','Nullifiers',11,'L');
insert into  Election values (1836,'Van Buren M','Democratic',170,'W');
insert into  Election values (1836,'Harrison W H','Whig',73,'L');
insert into  Election values (1836,'White H L','Whig',26,'L');
insert into  Election values (1836,'Webster D','Whig',14,'L');
insert into  Election values (1836,'Mangum W P','Anti-Jackson',11,'L');
insert into  Election values (1840,'Harrison W H','Whig',234,'W');
insert into  Election values (1840,'Van Buren M','Democratic',60,'L');
insert into  Election values (1844,'Polk J K','Democratic',170,'W');
insert into  Election values (1844,'Clay H','Whig',105,'L');
insert into  Election values (1848,'Taylor Z','Whig',163,'W');
insert into  Election values (1848,'Cass L','Democratic',127,'L');
insert into  Election values (1852,'Pierce F','Democratic',254,'W');
insert into  Election values (1852,'Scott W','Whig',42,'L');
insert into  Election values (1856,'Buchanan J','Democratic',174,'W');
insert into  Election values (1856,'Fremont J C','Republican',114,'L');
insert into  Election values (1856,'Fillmore M','Know-Nothing',8,'L');
insert into  Election values (1860,'Lincoln A','Republican',180,'W');
insert into  Election values (1860,'Breckinridge J C','Southern Dem',72,'L');
insert into  Election values (1860,'Douglas S A','Democratic',12,'L');
insert into  Election values (1860,'Bell J','Const. Union',39,'L');
insert into  Election values (1864,'Lincoln A','Republican',212,'W');
insert into  Election values (1864,'McClellan G B','Democratic',21,'L');
insert into  Election values (1868,'Grant U S','Republican',214,'W');
insert into  Election values (1868,'Seymour H','Democratic',80,'L');
insert into  Election values (1872,'Grant U S','Republican',286,'W');
insert into  Election values (1872,'Hendricks T A','Democratic',42,'L');
insert into  Election values (1872,'Brown B G','Democratic',18,'L');
insert into  Election values (1872,'Jenkins C J','Democratic',2,'L');
insert into  Election values (1872,'Davis D','Democratic',1,'L');
insert into  Election values (1876,'Hayes R B','Republican',185,'W');
insert into  Election values (1876,'Tilden S J','Democratic',184,'L');
insert into  Election values (1880,'Garfield J A','Republican',214,'W');
insert into  Election values (1880,'Hancock W S','Democratic',155,'L');
insert into  Election values (1884,'Cleveland G','Democratic',219,'W');
insert into  Election values (1884,'Blaine J G','Republican',182,'L');
insert into  Election values (1888,'Harrison B','Republican',233,'W');
insert into  Election values (1888,'Cleveland G','Democratic',168,'L');
insert into  Election values (1892,'Cleveland G','Democratic',277,'W');
insert into  Election values (1892,'Harrison B','Republican',145,'L');
insert into  Election values (1892,'Weaver J B','Populist',22,'L');
insert into  Election values (1896,'McKinley W','Republican',271,'W');
insert into  Election values (1896,'Bryan W J','Democratic',176,'L');
insert into  Election values (1900,'McKinley W','Republican',292,'W');
insert into  Election values (1900,'Bryan W J','Democratic',155,'L');
insert into  Election values (1904,'Roosevelt T','Republican',336,'W');
insert into  Election values (1904,'Parker A B','Democratic',140,'L');
insert into  Election values (1908,'Taft W H','Republican',321,'W');
insert into  Election values (1908,'Bryan W J','Democratic',162,'L');
insert into  Election values (1912,'Wilson W','Democratic',435,'W');
insert into  Election values (1912,'Roosevelt T','Progressive',88,'L');
insert into  Election values (1912,'Taft W H','Republican',8,'L');
insert into  Election values (1916,'Wilson W','Democratic',277,'W');
insert into  Election values (1916,'Hughes C E','Republican',254,'L');
insert into  Election values (1920,'Harding W G','Republican',404,'W');
insert into  Election values (1920,'Cox J M','Democratic',127,'L');
insert into  Election values (1924,'Coolidge C','Republican',382,'W');
insert into  Election values (1924,'Davis J W','Democratic',136,'L');
insert into  Election values (1924,'La Follette R M','Progressive',13,'L');
insert into  Election values (1928,'Hoover H C','Republican',444,'W');
insert into  Election values (1928,'Smith A E','Democratic',87,'L');
insert into  Election values (1932,'Roosevelt F D','Democratic',472,'W');
insert into  Election values (1932,'Hoover H C','Republican',59,'L');
insert into  Election values (1936,'Roosevelt F D','Democratic',523,'W');
insert into  Election values (1936,'Landon A M','Republican',8,'L');
insert into  Election values (1940,'Roosevelt F D','Democratic',449,'W');
insert into  Election values (1940,'Willkie W L','Republican',82,'L');
insert into  Election values (1944,'Roosevelt F D','Democratic',432,'W');
insert into  Election values (1944,'Dewey T E','Republican',99,'L');
insert into  Election values (1948,'Truman H S','Democratic',303,'W');
insert into  Election values (1948,'Dewey T E','Republican',189,'L');
insert into  Election values (1948,'Thurmond S','Dixiecrat',39,'L');
insert into  Election values (1952,'Eisenhower D D','Republican',442,'W');
insert into  Election values (1952,'Stevenson A E','Democratic',89,'L');
insert into  Election values (1956,'Eisenhower D D','Republican',457,'W');
insert into  Election values (1956,'Stevenso A E','Democratic',73,'L');
insert into  Election values (1956,'Jones W','Independent',1,'L');
insert into  Election values (1960,'Kennedy J F','Democratic',303,'W');
insert into  Election values (1960,'Nixon R M','Republican',219,'L');
insert into  Election values (1960,'Bird H F','Southern Dem',15,'L');
insert into  Election values (1964,'Johnson L B','Democratic',486,'W');
insert into  Election values (1964,'Goldwater B','Republican',52,'L');
insert into  Election values (1968,'Nixon R M','Republican',302,'W');
insert into  Election values (1968,'Humphrey H H','Democratic',191,'L');
insert into  Election values (1968,'Wallace G C','Independent',46,'L');
insert into  Election values (1972,'Nixon R M','Republican',520,'W');
insert into  Election values (1972,'McGovern G S','Democratic',17,'L');
insert into  Election values (1972,'Hospers J','Libertarian',1,'L');
insert into  Election values (1976,'Carter J E','Democratic',297,'W');
insert into  Election values (1976,'Ford G R','Republican',240,'L');
insert into  Election values (1980,'Reagan R','Republican',489,'W');
insert into  Election values (1980,'Carter J E','Democratic',49,'L');
insert into  Election values (1980,'Anderson J B','Independent',0,'L');
insert into  Election values (1984,'Reagan R','Republican',525,'W');
insert into  Election values (1984,'Mondale W','Democratic',13,'L');
insert into  Election values (1988,'Bush G H W','Republican',426,'W');
insert into  Election values (1988,'Dukakis M','Democratic',112,'L');
insert into  Election values (1992,'Clinton W J','Democratic',370,'W');
insert into  Election values (1992,'Bush G H W','Republican',168,'L');
insert into  Election values (1992,'Perot R','Independent',0,'L');
insert into  Election values (1996,'Clinton W J','Democratic',379,'W');
insert into  Election values (1996,'Dole B','Republican',159,'L');
insert into  Election values (1996,'Perot R','Reform',0,'L');
insert into  Election values (2000,'Bush G W','Republican',271,'W');
insert into  Election values (2000,'Gore A','Democratic',266,'L');
insert into  Election values (2004,'Bush G W','Republican',286,'W');
insert into  Election values (2004,'Kerry J','Democratic',251,'L');
insert into  Election values (2008,'Obama B H','Democratic',365,'W');
insert into  Election values (2008,'McCain J S','Republican',173,'L');
insert into  Election values (2012,'Obama B H','Democratic',332,'W');
insert into  Election values (2012,'Romney W M','Republican',206,'L');
insert into  Election values (2016,'Trump D J','Republican',306,'W');
insert into  Election values (2016,'Clinton H D R','Democratic',232,'L');
insert into  Election values (2020,'Biden J R','Democratic',306,'W');
insert into  Election values (2020,'Trump D J','Republican',232,'L');

-- ##################################################################

-- "This script gives read rights on all presidential tables to public ..."

-- grant select on president      to public;
-- grant select on state          to public;
-- grant select on pres_hobby     to public;
-- grant select on administration to public;
-- grant select on admin_pr_vp    to public;
-- grant select on pres_marriage  to public;
-- grant select on election       to public;

--   ##################################################################
commit;
GRANT USAGE ON SCHEMA president_public TO app;
GRANT SELECT ON ALL TABLES IN SCHEMA president_public to app;

