module Hilfe exposing (..)

import Html exposing (Html, div, text, p, ul, li, h2, h3, a, br)
import Html.Attributes exposing (style)

view : Html msg
view =
    div [ style "padding" "40px"
        , style "padding-top" "40px"
        , style "min-height" "100vh"
        , style "font-size" "18px"
        , style "font-family" "'Helvetica Neue', Arial, sans-serif"
        , style "background-color" "rgb(214,186,172)"
        , style "color" "#333"
        , style "display" "flex"
        , style "justify-content" "center"
        , style "align-items" "center"
        ]
        [ div [ style "background-color" "#fff"
              , style "padding" "20px"
              , style "border-radius" "8px"
              , style "box-shadow" "0 4px 8px rgba(0,0,0,0.1)"
              , style "max-width" "800px"
              , style "line-height" "1.6"
              , style "overflow-y" "auto"
              ]
            [ h2 [style "font-weight" "bold", style "font-size" "40px" ] [ text "Hilfe für dich" ]
            , p [] [ text "Bookshelf_online ist eine interaktive Webseite, die es dir ermöglicht, ein virtuelles Bücherregal nach deinen Wünschen zu gestalten und anzupassen. Hier sind die Hauptfunktionen und hilfreiche Tipps zur Nutzung unserer Webseite:" ]
            , h3 [style "font-weight" "bold", style "font-size" "25px" ] [ text "Hauptfunktionen" ]
            , ul []
                [ li [style "font-weight" "bold"] [ text "Regalnamen eingeben:" ]
                , ul []
                    [ li [] [ text "Direkt über deinem Regal befindet sich der Schriftzug \"Mein Bücherregal\". Diesen kannst du durch anklicken einfach bearbeiten und durch einen beliebigen anderen Text ersetzen. Bist du mit der Eingabe zufrieden, klicke einfach auf eine beliebige Stelle auf der Webseite und der Name wird geändert und gespeichert. Du kannst ihn selbstverständlich jeder Zeit wieder ändern." ]
                    ]
                ,li [style "font-weight" "bold"] [ text "Regalfarben anpassen:" ]
                , ul []
                    [ li [] [ text "Klicke auf die Farbpalette am rechten Rand und es wird sich ein Farbmenü öffnen." ]
                    , li [] [ text "Du kannst durch Klicken auf eine bestimmte Stelle des Regals, wie ein Regalbrett, eine Seitenwand oder die Rückwand, den Bereich auswählen, den du einfärben möchtest. Du erkennst, dass ein Bereich ausgewählt ist daran, dass er schwarz umrandet ist." ]
                    , li [] [ text "Nachdem du ein Objekt ausgwählt hast kannst du zu den Farbeingaben übergehen. Gib für jeden Farbwert: Rot, Grün und Blau; einen Wert zwischen 0 und 255 ein." ]
                    , li [] [ text "Um das ausgewählte Objekt zu färben musst du jetzt noch auf \"Farbe ändern\" klicken." ]
                    , li [] [ text "Nun kannst du das nächste Objekt anklicken und einfärben. Es bleibt immer deine letzte Eingabe gespeichert, also musst du nicht immer wieder die selben 3 Werte eingeben, wenn du meherer Objekte in der selben Farbe haben möchtest."]
                    , li [] [ text "Wenn du fertig bist, kannst du bei erneutem klicken auf die Farbpalette, die Farbeingabe wieder schließen." ]
                    ]
                , li [style "font-weight" "bold"] [ text "Navigation und Seiten:" ]
                , ul []
                    [ li [] [ text "Du kannst die Navigationsleiste am oberen Rand nutzen, um zwischen den verschiedenen Seiten der Webseite zu wechseln, wie \"Bookshelf\", \"Suche\", \"Empfehlungen\" und \"Hilfe\"." ]
                    , li [] [ text "Die Bookshelf Seite ist die wichtigste Seite. Hier dreht sich alles um das Design deines Bücherregals."]
                    , li [] [ text "Auf der Suche Seite kannst du Büchern suchen und dir Informationen zu dem Buch, wie dem Autor, dem Erscheinungsjahr und einer kurzen Beschreibung des Buches anzeigen lassen. Klicke dafür einfach in die Suchleiste und gib ein Stichwort ein. Dir wird nun eine Liste von Büchern angezeit, die deine Eingabe beinhalten. Hast du dich für ein Buch entschieden, klicke einfach auf den Titel und du erhälst weitere Informationen über das Buch. "]
                    , li [] [ text "Befindest du dich auf der Empfelungen Seite, kannst du ganz ohne Angabe eines Stichwortes dich durch die Bücher stöbern."]
                    ]
                ]
            , h3 [style "font-weight" "bold", style "font-size" "25px" ] [ text "Tipps" ]
            , ul []
                [ li [style "font-weight" "bold"] [ text "Farbauswahl:" ]
                , ul []
                    [ li [] [ text "Experimentiere mit verschiedenen Farbwerten, um die ideale Farbgebung für dein Regal zu finden. Nutze die Farbcodes (RGB) gezielt, um spezifische Farben zu erzielen. Benutze gerne dafür einen online RGB Generator, dann kannst du direkt sehen, welche Farbe du gerade zusammenmischst. Hier ist eine Empfehlung von uns: " 
                    , a [Html.Attributes.href "https://rgbcolorpicker.com/"] [text "RGB_Farbgenerator"]]
                    ]
                ]
            , br [] []
            , p [style "font-size" "20px"] [ text "Mit diesen Funktionen und Tipps kannst du dein Bücherregal ganz nach deinen Vorstellungen gestalten und optimal nutzen. Viel Spaß beim Designen wünschen dir Lara und Jonas!" ]
            ]
        ]
